<?php

/* HLTV stuff 0.1
 * 
 * As requested by ghostofmybrain at AlliedMods.net: http://forums.alliedmods.net/showthread.php?t=180899
 *
 * Requirements:
 * PHP 5.2.8 or higher, with PDO
 * MySQL 5 or higher
 *
 * This script makes use of xPaw's PHP-Source-Query-Class, which can be found at https://github.com/xPaw/PHP-Source-Query-Class
 * This script is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/3.0/
 */

if (php_sapi_name() != 'cli') {
  die();
}

require_once('../lib/db.php');
require_once('SourceQuery.class.php');

$sql = "SELECT
  hlds.id,
  hlds.name,
  INET_NTOA(hlds.ip) AS ip,
  hlds.port,
  hlds.min_playercount,
  hlds.recording,
  hlds.monitor,
  hlds.hltv_name,
  INET_NTOA(hlds.hltv_ip) AS hltv_ip,
  hlds.hltv_port,
  hlds.hltv_rcon_password,
  hlds.hltv_demo_prefix
  FROM
  hlds
  ORDER BY id ASC";

$stmt = $db_handle->query($sql);

if ($stmt->errorCode() > 0) {
  $errors = $stmt->errorInfo();
  return $errors;
}
elseif ($stmt->rowCount() > 0) {
  $result = $stmt->fetchALL();
  foreach ($result as $row) {
    echo $row['name'] . ' - ' . $row['ip'] . ':' . $row['port'] . ' - id ' . $row['id'] . PHP_EOL;
    if ($row['monitor'] == 1) {
// HLDS should be monitored
      echo $row['name'] . ' should be monitored' . PHP_EOL;
      $info = queryHLDS($row);
      if (!is_array($info)) {
// error querying HLDS
        if (is_string($info)) {
          echo $info . PHP_EOL;
        }
        elseif ($info == false) {
          echo 'Could not connect to ' . $row['ip'] . ':' . $row['port'] . PHP_EOL;
        }
      }
      elseif ($info['Players'] >= $row['min_playercount']) {
        echo $info['Players'] . ' players detected...' . PHP_EOL;
        if ($row['recording'] != 1) {
// HLTV is not recording, but should be
          echo 'Minimum player count reached, will tell HLTV to start recording' . PHP_EOL;
          $info = queryHLTV($row, 'start');
          if ($info === true) {
            //set recording to 1 in database
            updateDB($row['id'], 1, $db_handle);
            echo 'HLTV ' . $row['hltv_name'] . ' - ' . $row['hltv_ip'] . ':' . $row['hltv_port'] . ' started recording - OK' . PHP_EOL;
          }
          else {
            echo $info . ' - ERROR' . PHP_EOL;
          }
        }
        else {
          echo $row['name'] . ' is already being recorded - OK' . PHP_EOL;
        }
      }
      elseif ($info['Players'] < $row['min_playercount']) {
        echo $info['Players'] . ' players detected...' . PHP_EOL;
        if ($row['recording'] == 1) {
// HLTV is recording, but shouldn't be
          echo 'Minimum player count not reached, will tell HLTV to stop recording' . PHP_EOL;
          $info = queryHLTV($row, 'stop');
          if (is_bool($info) && ($info == true)) {
            //set recording to 0 in database
            updateDB($row['id'], 0, $db_handle);
            echo 'HLTV ' . $row['hltv_name'] . ' - ' . $row['hltv_ip'] . ':' . $row['hltv_port'] . ' stopped recording - OK' . PHP_EOL;
          }
          else {
            echo $info . ' - ERROR' . PHP_EOL;
          }
        }
        else {
          echo 'Minimum player count not reached, but HLTV isn\'t recording anyway - OK';
        }
      }
      echo '-----------------------------' . PHP_EOL;
    }
    else {
// HLDS should not be monitored
      echo $row['name'] . ' should not be monitored' . PHP_EOL;
      if ($row['recording'] == 1) {
        echo $row['name'] . ' is being recorded' . PHP_EOL;
// HLTV is recording
// send command to stop recording
        $info = queryHLTV($row, 'stop');
        if ($info === true) {
          //set recording to 0 in database
          updateDB($row['id'], 0, $db_handle);
          echo 'HLTV ' . $row['hltv_name'] . ' - ' . $row['hltv_ip'] . ':' . $row['hltv_port'] . ' stopped recording - OK' . PHP_EOL;
        }
        else {
          echo $info . ' - ERROR' . PHP_EOL;
        }
      }
      else {
        echo $row['name'] . ' is not being recorded - OK' . PHP_EOL;
      }
      echo '-----------------------------' . PHP_EOL;
    }
  }
}

function updateDB($id, $recording, $db_handle) {
//change recording status in database
  $stmt = $db_handle->prepare("UPDATE hlds SET recording = :recording WHERE id = :id");
  $stmt->bindParam(':id', $id, PDO::PARAM_INT);
  $stmt->bindParam(':recording', $recording, PDO::PARAM_INT);
  $stmt->execute();
}

function queryHLDS($hlds) {
  $Query = new SourceQuery();
  try {
    $Query->Connect($hlds['ip'], $hlds['port']);
    $Info = $Query->GetInfo();
    $Query->Disconnect();
    return $Info;
  } catch (SQueryException $e) {
    $Query->Disconnect();
    return $e->getMessage() . ' - ERROR';
  }
}

function queryHLTV($hlds, $command) {
  $Query = new SourceQuery();
  try {
    $Query->Connect($hlds['hltv_ip'], $hlds['hltv_port'], 3, SourceQuery :: GOLDSOURCE);
    $Query->SetRconPassword($hlds['hltv_rcon_password']);
    switch ($command) {
      case 'start': $Info = $Query->Rcon('record ' . $hlds['hltv_demo_prefix']);
        break;
      case 'stop': $Info = $Query->Rcon('stop');
    }
    $Query->Disconnect();
    return true;
  } catch (SQueryException $e) {
    $Query->Disconnect();
    return $e->getMessage() . ' - ERROR';
  }
}

?>