<?php
/* HLTV stuff 0.1
 * 
 * As requested by ghostofmybrain at AlliedMods.net: http://forums.alliedmods.net/showthread.php?t=180899
 *
 * Requirements:
 * PHP 5.2.8 or higher, with PDO
 * MySQL 5 or higher

 * This script is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details.
 */

class HLDS {

  public $db;
// HLDS properties
  public $id;
  public $name;
  public $ip;
  public $port;
  public $min_playercount;
  public $monitor;
// HLTV properties
  public $hltv_name;
  public $hltv_ip;
  public $hltv_port;
  public $hltv_rcon_password;
  public $hltv_demo_prefix;

  public function __construct($db_handle) {
    $this->db = $db_handle;
  }

  public function getByID($id) {
    if (is_int($id)) {
      $stmt = $this->db->prepare("SELECT name, INET_NTOA(ip) AS ip, port, min_playercount, monitor, hltv_name, INET_NTOA(hltv_ip) AS hltv_ip, hltv_port, hltv_rcon_password, hltv_demo_prefix FROM hlds WHERE id = :id");
      $stmt->bindParam(':id', $id, PDO::PARAM_INT);
      $stmt->execute();
      if ($stmt->errorCode() > 0) {
        foreach ($stmt->errorInfo() as $error) {
          $this->error($error);
        }
      }
      $count = $stmt->rowCount();
      if ($count > 0) {
        $result = $stmt->fetch();

        $this->id = $id;
        $this->name = $result['name'];
        $this->ip = $result['ip'];
        $this->port = $result['port'];
        $this->min_playercount = $result['min_playercount'];
        $this->monitor = $result['monitor'];
        $this->hltv_name = $result['hltv_name'];
        $this->hltv_ip = $result['hltv_ip'];
        $this->hltv_port = $result['hltv_port'];
        $this->hltv_rcon_password = $result['hltv_rcon_password'];
        $this->hltv_demo_prefix = $result['hltv_demo_prefix'];

        return $this;
      }
      else {
        $this->error('Could not retrieve HLTV with id ' . $id);
      }
    }
    else {
      $this->error('Invalid HLDS');
    }
  }

  public function save() {
    if ($this->id) {
      $stmt = $this->db->prepare("UPDATE hlds SET 
        name = :name,
        ip = INET_ATON(:ip),
        port = :port,
        min_playercount = :min_playercount,
        monitor = :monitor,
        hltv_name = :hltv_name,
        hltv_ip = INET_ATON(:hltv_ip),
        hltv_port = :hltv_port,
        hltv_rcon_password = :hltv_rcon_password,
        hltv_demo_prefix = :hltv_demo_prefix
        WHERE id = :id");
      $stmt->bindParam(':name', $this->name, PDO::PARAM_STR);
      $stmt->bindParam(':ip', $this->ip, PDO::PARAM_STR);
      $stmt->bindParam(':port', $this->port, PDO::PARAM_INT);
      $stmt->bindParam(':min_playercount', $this->min_playercount, PDO::PARAM_INT);
      $stmt->bindParam(':monitor', $this->monitor, PDO::PARAM_INT);
      $stmt->bindParam(':hltv_name', $this->hltv_name, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_ip', $this->hltv_ip, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_port', $this->hltv_port, PDO::PARAM_INT);
      $stmt->bindParam(':hltv_rcon_password', $this->hltv_rcon_password, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_demo_prefix', $this->hltv_demo_prefix, PDO::PARAM_STR);
      $stmt->bindParam(':id', $this->id, PDO::PARAM_INT);

      if ($stmt->execute() !== true) {
        if ($stmt->errorCode() > 0) {
          foreach ($stmt->errorInfo() as $error) {
            $this->error($error);
          }
        }
        else {
          $this->error('Could not update HLDS with id ' . $this->id);
        }
      }
      else {
        $this->success('Updated HLDS with id ' . $this->id);
      }
    }
    else {
      $stmt = $this->db->prepare("INSERT INTO hlds SET 
        name = :name,
        ip = INET_ATON(:ip),
        port = :port,
        min_playercount = :min_playercount,
        monitor = :monitor,
        hltv_name = :hltv_name,
        hltv_ip = INET_ATON(:hltv_ip),
        hltv_port = :hltv_port,
        hltv_rcon_password = :hltv_rcon_password,
        hltv_demo_prefix = :hltv_demo_prefix");
      $stmt->bindParam(':name', $this->name, PDO::PARAM_STR);
      $stmt->bindParam(':ip', $this->ip, PDO::PARAM_STR);
      $stmt->bindParam(':port', $this->port, PDO::PARAM_INT);
      $stmt->bindParam(':min_playercount', $this->min_playercount, PDO::PARAM_INT);
      $stmt->bindParam(':monitor', $this->monitor, PDO::PARAM_INT);
      $stmt->bindParam(':hltv_name', $this->hltv_name, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_ip', $this->hltv_ip, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_port', $this->hltv_port, PDO::PARAM_INT);
      $stmt->bindParam(':hltv_rcon_password', $this->hltv_rcon_password, PDO::PARAM_STR);
      $stmt->bindParam(':hltv_demo_prefix', $this->hltv_demo_prefix, PDO::PARAM_STR);

      if ($stmt->execute() !== true) {
        if ($stmt->errorCode() > 0) {
          foreach ($stmt->errorInfo() as $error) {
            $this->error($error);
          }
        }
        else {
          $this->error('Could not save new HLDS');
        }
      }
      else {
        $this->success('Saved new HLDS');
      }
    }
  }

  public function error($error) {
    return $this->errors[] = $error;
  }

  public function success($success) {
    return $this->success = $success;
  }

}

?>
