<?php
/* HLTV stuff 0.1
 * 
 * As requested by ghostofmybrain at AlliedMods.net: http://forums.alliedmods.net/showthread.php?t=180899
 *
 * Requirements:
 * PHP 5.2.8 or higher, with PDO
 * MySQL 5 or higher

 * This script is free software. It comes without any warranty, to
 * the extent permitted by applicable law. You can redistribute it
 * and/or modify it under the terms of the Do What The Fuck You Want
 * To Public License, Version 2, as published by Sam Hocevar. See
 * http://sam.zoy.org/wtfpl/COPYING for more details.
 */

function printMessages($messages, $return = false) {
  if (is_array($messages)) {
    echo '<div class="errors">';
    foreach ($messages as $message) {
      echo $message . '<br>';
      if ($return === true) {
        echo '<br>Returning to <a href="index.php">index</a> in 5 seconds...';
      }
    }
    echo '</div>';
  }
  else {
    echo '<div class="success">';
    echo $messages . '<br>';
    echo '<br>Returning to <a href="index.php">index</a> in 5 seconds...';
    echo '</div>';
  }
}

function validateInput($input) {
  $errors = array();

  if ($input['name'] == '')
    $errors[] = 'HLDS name cannot be empty';
  if ($input['ip'] == '')
    $errors[] = 'HLDS ip cannot be empty';
  if ($input['ip'] != '' && !filter_var($input['ip'], FILTER_VALIDATE_IP))
    $errors[] = 'HLDS ip is invalid';
  if ($input['port'] == '')
    $errors[] = 'HLDS port cannot be empty';
  if ($input['port'] != '' && !is_numeric($input['port']))
    $errors[] = 'HLDS port has to be an integer';
  if (($input['port'] != '') && ($input['port'] < 1024 || $input['port'] > 65535))
    $errors[] = 'HLDS port must be between 1024 and 65535';
  if ($input['min_playercount'] == '')
    $errors[] = 'minimum player count cannot be empty';
  if ($input['min_playercount'] != '' && !is_numeric($input['min_playercount']))
    $errors[] = 'minimum player count has to be an integer';
  if (($input['min_playercount'] != '') && ($input['min_playercount'] < 0 || $input['min_playercount'] > 31))
    $errors[] = 'minimum player cannot be lower than 0 and higher than 31';
  if (isset($input['monitor'])) {
    if ($input['monitor'] == '')
      $errors[] = 'monitor cannot be empty';
    if ($input['monitor'] != '' && !is_numeric($input['monitor']))
      $errors[] = 'monitor has to be either yes or no';
  }
  if ($input['hltv_name'] == '')
    $errors[] = 'HLTV name cannot be empty';
  if ($input['hltv_name'] == '')
    $errors[] = 'HLTV name cannot be empty';
  if ($input['hltv_ip'] == '')
    $errors[] = 'HLTV ip cannot be empty';
  if ($input['hltv_ip'] != '' && !filter_var($input['hltv_ip'], FILTER_VALIDATE_IP))
    $errors[] = 'HLTV ip format is invalid ';
  if ($input['hltv_port'] == '')
    $errors[] = 'HLTV port cannot be empty';
  if ($input['hltv_port'] != '' && !is_numeric($input['hltv_port']))
    $errors[] = 'HLTV port has to be an integer';
  if (($input['hltv_port'] != '') && ($input['hltv_port'] < 1024 || $input['hltv_port'] > 65535))
    $errors[] = 'HLTV port must be between 1024 and 65535';
  if ($input['hltv_rcon_password'] == '')
    $errors[] = 'HLTV rcon password cannot be empty';

  return $errors;
}

function loadAll($db_handle) {
  $errors = array();

  $sql = "SELECT
  hlds.id,
  hlds.name,
 	INET_NTOA(hlds.ip) AS ip,
  hlds.port,
  hlds.min_playercount,
  hlds.recording,
  hlds.monitor,
  hlds.hltv_name,
  INET_NTOA(hlds.hltv_ip) AS hltv_ip,
  hlds.hltv_port,
  hlds.hltv_rcon_password,
  hlds.hltv_demo_prefix
FROM
  hlds";
  $stmt = $db_handle->query($sql);

  if (!$stmt) {
    return 'Could not retrieve data...';
  }
  elseif ($stmt->rowCount() > 0) {
    $result = $stmt->fetchALL();
    return $result;
  }
  else {
    return 'Could not retrieve data...';
  }
}

function printForm($hlds = null) {
  ?>
  <form action="edit.php" method="post">
    <fieldset>
      <?php
      if (isset($hlds->id)) {
        echo '<input type="hidden" name="id" value="' . $hlds->id . '">';
      }
      ?>
      <label for="name">HLDS name</label>
      <input type="text" name="name" id="name" value="<?php echo (isset($hlds->name) ? htmlspecialchars($hlds->name) : null) ?>">
      <label for="ip">HLDS ip</label>
      <input type="text" name="ip" id="ip" value="<?php echo (isset($hlds->ip) ? $hlds->ip : null) ?>">
      <label for="port">HLDS port</label>
      <input type="number" min="1024" max="65535" name="port" id="port" <?php echo (isset($hlds->port) ? 'value="' . $hlds->port . '"' : null) ?>>
      <label for="min_playercount">HLDS min players</label>
      <input type="number" min="0" max="31" name="min_playercount" id="min_playercount" <?php echo (isset($hlds->min_playercount) ? 'value="' . $hlds->min_playercount . '"' : null) ?>>
      <label for="monitor">HLDS monitor</label>
      <input type="checkbox" name="monitor" id="monitor" value="1" <?php echo (isset($hlds->monitor) && $hlds->monitor == 1 ? ' checked="true"' : null) ?>>
      <label for="hltv_name">HLTV name</label>
      <input type="text" name="hltv_name" id="hltv_name" value="<?php echo (isset($hlds->hltv_name) ? htmlspecialchars($hlds->hltv_name) : null) ?>">
      <label for="hltv_ip">HLTV ip</label>
      <input type="text" name="hltv_ip" id="hltv_ip" value="<?php echo (isset($hlds->hltv_ip) ? $hlds->hltv_ip : null) ?>">
      <label for="hltv_port">HLTV port</label>
      <input type="number" min="1024" max="65535" name="hltv_port" id="hltv_port" <?php echo (isset($hlds->hltv_port) ? 'value="' . $hlds->hltv_port . '"' : null) ?>>
      <label for="hltv_rcon_password">HLTV rcon password</label>
      <input type="text" name="hltv_rcon_password" id="hltv_rcon_password" value="<?php echo (isset($hlds->hltv_rcon_password) ? htmlspecialchars($hlds->hltv_rcon_password) : null) ?>">
      <label for="hltv_demo_prefix">HLTV demo prefix</label>
      <input type="text" name="hltv_demo_prefix" id="hltv_demo_prefix" value="<?php echo (isset($hlds->hltv_demo_prefix) ? htmlspecialchars($hlds->hltv_demo_prefix) : null) ?>">
      <input type="submit" name="submit" value="submit">
    </fieldset>
  </form>
  <?php
}
?>
